# Class: friendica
# ===========================
#
# Puppet class to install and configure a Friendica instance
# Friendica is a federated social platform.
# http://friendica.com
#
# Parameters
# ----------
#
# Document parameters here.
#
# * `tls_key`
#
# Allow you to inject a TLS key that comes from eg encrypted hiera
# (eyaml)
#
# * `service_name`
#
# The DNS name the friendica instance should serve. Defaults to the
# full qualified domain name of the server / node.
#
# * `admin_mail`
#
# Working email address of the server admin. Use this email address to
# register the first account on your Friendica instance after setup.
# Defauls to info@`service_name`
#
# * `mysql_web_user`
#
# The mysql user name that the friendica application uses to connect
# to mysql. Defaults to friendica-www
#
# * `mysql_web_password`
#
# THe mysql password that the friendica application uses to connect
# to mysql. Has a default which may be ok if MySQL security is otherwise
# sane. But feeding it an eyaml encrypted alternative is better.
#
# * `mysql_db_name`
#
# MySQL database name to use, defaults to 'friendica'
#
# * `branch`
#
# The Friendica code is deployed using a git clone command. This
# options allows you to specify an alternative git branch to check out
# Defaults to develop.
#
# Please note the the checkout is only performed during setup. Updates
# currently must be done manually using a git pull.
#
# * `download_url`
#
# Option to specify an other GIT repository, defaults to the friendica
# public repo on Github.
#
# * `manage_mysql`
#
# Wether to setup MySQL using the included puppet code. Defaults to true.
#
# * `manage_nginx`
#
# Wether to setup nginx using the included puppet code. Defaults to true.
#
# * `manage_php`
#
# Wether to setup php/php-fpm using the included puppet code. Defaults to true.
#
# * `manage_nscd`
#
# Wether to setup nscd (name serving caching daemon) using the included puppet code. Defaults to true.
#
# * `manage_firewall`
#
# Wether to setup a firewall rule using the included puppet code. Defaults to true.

# Examples
# --------
#
# @example
#    class { 'friendica':
#      $service_name => "mycoolnodename.org",
#      $admin_email => "sittingduck@aol.com",
#    }
#
# Authors
# -------
#
# Eelco Maljaars <eelco@maljaars-it.nl>
#
# Copyright
# ---------
#
# Copyright 2017 Eelco Maljaars, unless otherwise noted.
#
class friendica(

  $tls_key            = undef,
  $service_name       = $::fqdn,
  $admin_email        = "info@${service_name}",
  $mysql_web_user     = 'friendica-www',
  $mysql_web_password = '8vh37hg24tfsrfe',
  $mysql_db_name      = 'friendica',
  $branch             = 'develop',
  $download_url       = 'https://github.com/friendica/friendica.git',
  $manage_mysql       = true,
  $manage_ngingx      = true,
  $manage_nscd        = true,
  $manage_php         = true,
  $manage_firewall    = true,

) {

  if $manage_nscd     { contain friendica::nscd  }
  if $manage_mysql    { contain friendica::mysql }
  if $manage_php      { contain friendica::php   }
  if $manage_nginx    { contain friendica::nginx }
  if $manage_firewall { contain friendica::firewall }

  contain friendica::install
  contain friendica::configure

}
